@@ -1,24 +1,27 @@
+# (c) Copyright 2014,2015 Hewlett-Packard Development Company, L.P.
+# (c) Copyright 2016 Hewlett-Packard Enterprise Development Company, L.P.
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 """
-(c) Copyright 2014,2015 Hewlett-Packard Development Company, L.P.
-(c) Copyright 2016 Hewlett-Packard Enterprise Development Company, L.P.
-Licensed under the Apache License, Version 2.0 (the "License");
-you may not use this file except in compliance with the License.
-You may obtain a copy of the License at
-
-    http://www.apache.org/licenses/LICENSE-2.0
-
-Unless required by applicable law or agreed to in writing, software
-distributed under the License is distributed on an "AS IS" BASIS,
-WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-See the License for the specific language governing permissions and
-limitations under the License.
-
 Freezer general utils functions
 """
+
+import threading
+
 from oslo_log import log
 from six.moves import queue
 
-import threading
 
 LOG = log.getLogger(__name__)
 
@@ -113,4 +116,4 @@ class QueuedThread(threading.Thread):
             self.rich_queue.force_stop()
             # Thread will exit at this point.
             # @todo print the error using traceback.print_exc(file=sys.stdout)
-            raise e
+            raise
